@@ -1,5 +1,6 @@
 from calendar import timegm
 from datetime import datetime, timedelta
+from time import timezone
 
 import pytz
 import times
@@ -20,10 +21,13 @@ class Moment(MutableDate):
         self._formula = formula
 
     def now(self):
+        """Create a moment with the current datetime."""
         self._date = datetime.now()
+        self._formula = "%Y-%m-%d"
         return self
 
     def utc(self, *args):
+        """Create a moment from a UTC date."""
         date, formula = parse_date_and_formula(*args)
         self._date = pytz.timezone('UTC').localize(date)
         self._formula = formula
@@ -32,6 +36,7 @@ class Moment(MutableDate):
     def utcnow(self):
         """UTC equivalent to now."""
         self._date = pytz.timezone('UTC').localize(datetime.utcnow())
+        self._formula = "%Y-%m-%d"
         return self
 
     def unix(self, timestamp, utc=False):
@@ -83,6 +88,7 @@ class Moment(MutableDate):
         return self._date.strftime(formula)
 
     def diff(self, moment, measurement=None):
+        """Return the difference between moments."""
         return self - moment
 
     def done(self):
@@ -97,12 +103,12 @@ class Moment(MutableDate):
         """Same as clone."""
         return Moment(self._date)
 
-    @property
-    def date(self):
-        """Access the internal datetime variable."""
-        return self._date
-
     def __repr__(self):
         if self._date is not None:
             return "<Moment(%s)>" % (self._date.strftime(self._formula))
         return "<Moment>"
+
+    def __str__(self):
+        formatted = self._date.strftime('%Y-%m-%dT%H:%M:%S')
+        tz = str.format('{0:+06.2f}', -float(timezone) / 3600)
+        return formatted + tz
